@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,27 +30,28 @@ import (
 )
 
 func usage() {
-	fmt.Fprintf(os.Stderr, nncp.UsageHeader())
-	fmt.Fprintf(os.Stderr, "nncp-freq -- send file request\n\n")
+	fmt.Fprint(os.Stderr, "nncp-freq -- send file request\n\n")
 	fmt.Fprintf(os.Stderr, "Usage: %s [options] NODE:SRC [DST]\nOptions:\n", os.Args[0])
 	flag.PrintDefaults()
 }
 
 func main() {
 	var (
-		cfgPath      = flag.String("cfg", nncp.DefaultCfgPath, "Path to configuration file")
-		niceRaw      = flag.String("nice", nncp.NicenessFmt(nncp.DefaultNiceFreq), "Outbound packet niceness")
-		replyNiceRaw = flag.String("replynice", nncp.NicenessFmt(nncp.DefaultNiceFile), "Reply file packet niceness")
-		minSize      = flag.Uint64("minsize", 0, "Minimal required resulting packet size, in KiB")
-		viaOverride  = flag.String("via", "", "Override Via path to destination node")
-		spoolPath    = flag.String("spool", "", "Override path to spool")
-		logPath      = flag.String("log", "", "Override path to logfile")
-		quiet        = flag.Bool("quiet", false, "Print only errors")
-		showPrgrs    = flag.Bool("progress", false, "Force progress showing")
-		omitPrgrs    = flag.Bool("noprogress", false, "Omit progress showing")
-		debug        = flag.Bool("debug", false, "Print debug messages")
-		version      = flag.Bool("version", false, "Print version information")
-		warranty     = flag.Bool("warranty", false, "Print warranty information")
+		cfgPath = flag.String("cfg", nncp.DefaultCfgPath, "Path to configuration file")
+		niceRaw = flag.String("nice", nncp.NicenessFmt(nncp.DefaultNiceFreq),
+			"Outbound packet niceness")
+		replyNiceRaw = flag.String("replynice", nncp.NicenessFmt(nncp.DefaultNiceFile),
+			"Reply file packet niceness")
+		minSize     = flag.Uint64("minsize", 0, "Minimal required resulting packet size, in KiB")
+		viaOverride = flag.String("via", "", "Override Via path to destination node")
+		spoolPath   = flag.String("spool", "", "Override path to spool")
+		logPath     = flag.String("log", "", "Override path to logfile")
+		quiet       = flag.Bool("quiet", false, "Print only errors")
+		showPrgrs   = flag.Bool("progress", false, "Force progress showing")
+		omitPrgrs   = flag.Bool("noprogress", false, "Omit progress showing")
+		debug       = flag.Bool("debug", false, "Print debug messages")
+		version     = flag.Bool("version", false, "Print version information")
+		warranty    = flag.Bool("warranty", false, "Print warranty information")
 	)
 	log.SetFlags(log.Lshortfile)
 	flag.Usage = usage
