@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,9 +28,7 @@ import (
 	xdr "github.com/davecgh/go-xdr/xdr2"
 )
 
-const (
-	MCDPort = 5400
-)
+const MCDPort = 5400
 
 type MCD struct {
 	Magic  [8]byte
