@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -82,9 +82,7 @@ type MTHSeq struct {
 	size        int64
 	prependSize int64
 	toSkip      int64
-	skipped     bool
 	finished    bool
-	pktName     string
 }
 
 func MTHSeqNew(size, offset int64) *MTHSeq {
