@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -50,6 +50,8 @@ type Node struct {
 	FreqChunked    int64
 	FreqMinSize    int64
 	FreqMaxSize    int64
+	ACKNice        uint8
+	ACKMinSize     int64
 	Via            []*NodeId
 	Addrs          map[string]string
 	RxRate         int
