@@ -1,6 +1,6 @@
 /*
 NNCP -- Node to Node copy, utilities for store-and-forward data exchange
-Copyright (C) 2016-2022 Sergey Matveev <stargrave@stargrave.org>
+Copyright (C) 2016-2023 Sergey Matveev <stargrave@stargrave.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -146,7 +146,7 @@ func TestPktEncRead(t *testing.T) {
 		}
 		var pktBuf bytes.Buffer
 		xdr.Marshal(&pktBuf, &pkt)
-		return bytes.Compare(pt.Bytes(), append(pktBuf.Bytes(), data...)) == 0
+		return bytes.Equal(pt.Bytes(), append(pktBuf.Bytes(), data...))
 	}
 	if err := quick.Check(f, nil); err != nil {
 		t.Error(err)
